diff --git a/+af_tools/@Airfoil/Airfoil.m b/+af_tools/@Airfoil/Airfoil.m
index a5ebfd29d86fa3f8648ef009e11ea4df6598b4c3..9bfedc302f9420bb375afa2573baaba209522bb8 100644
--- a/+af_tools/@Airfoil/Airfoil.m
+++ b/+af_tools/@Airfoil/Airfoil.m
@@ -97,6 +97,10 @@ classdef Airfoil
             self.Polar = self.Polar.extendpolar();
         end
 
+        function self = analyze(self)
+            self.Polar = self.Polar.analyze();
+        end
+
         self = addextremereynolds(self)
 
     end
diff --git a/CHANGELOG.md b/CHANGELOG.md
index ad2dda8fd57de30f1216f1865384644945280e97..0ce5962c7c17ea394d259563784577b1380e4152 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -14,6 +14,8 @@ and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0
 
 ### Changed
 
+- **Polar**: rename _analyse_ method in _analyze_ to use US spelling everywhere.
+
 ### Deprecated
 
 ### Removed
diff --git a/+af_tools/@Polar/Polar.m b/+af_tools/@Polar/Polar.m
index dd99a43618286d7d05993660bd72c7c022f98ba1..2dd433e3c77b5db603dcb6856669ae3882d74a0c 100644
--- a/+af_tools/@Polar/Polar.m
+++ b/+af_tools/@Polar/Polar.m
@@ -136,8 +136,8 @@ classdef Polar
         end
 
         % ---------------------------------------
-        function self = analyse(self)
-            % ANALYSE  Get all useful information from the polar curves at once
+        function self = analyze(self)
+            % ANALYZE  Get all useful information from the polar curves at once
             %
             % See also: af_tools.findstall, af_tools.findzerolift, af_tools.findcllinrange.
 